@@ -3,7 +3,11 @@ import numpy as np
 from girth import irt_evaluation
 
 
-def create_correlated_abilities(correlation_matrix, n_participants):
+__all__ = ["create_correlated_abilities", "create_synthetic_irt_dichotomous",
+           "create_synthetic_mirt_dichotomous", "create_synthetic_irt_polytomous"]
+
+
+def create_correlated_abilities(correlation_matrix, n_participants, seed=None):
     """ Creates correlated ability parameters based on an input correlation matrix.
 
     This is a helper function for use in synthesizing multi-dimensional data
@@ -13,13 +17,15 @@ def create_correlated_abilities(correlation_matrix, n_participants):
         correlation_matrix: (2d array) Symmetric matrix defining
                             the correlation between the abilities
         n_participants: number of participants to synthesize
+        seed: Random Number Generator seed (None by default)
 
     Returns:
         abilities: (2d array) correlated abilities
     """
+    rng = np.random.default_rng(seed)
     lower = np.linalg.cholesky(correlation_matrix)
 
-    return lower @ np.random.randn(correlation_matrix.shape[0], n_participants)
+    return lower @ rng.standard_normal((correlation_matrix.shape[0], n_participants))
 
 
 def create_synthetic_irt_dichotomous(difficulty, discrimination, thetas,
@@ -43,8 +49,7 @@ def create_synthetic_irt_dichotomous(difficulty, discrimination, thetas,
         synthetic_data: (2d array) realization of possible response given parameters
 
     """
-    if seed:
-        np.random.seed(seed)
+    rng = np.random.default_rng(seed)
 
     if np.ndim(guessing) < 1:
         guessing = np.full_like(difficulty, guessing)
@@ -56,7 +61,7 @@ def create_synthetic_irt_dichotomous(difficulty, discrimination, thetas,
     continuous_output += guessing[:, None]
 
     # convert to binary based on probability
-    random_compare = np.random.rand(*continuous_output.shape)
+    random_compare = rng.uniform(size=continuous_output.shape)
 
     return (random_compare <= continuous_output).astype('int')
 
@@ -88,8 +93,7 @@ def create_synthetic_mirt_dichotomous(difficulty, discrimination, thetas,
 
         synthetic_data = create_synthetic_mirt_dichotomous(difficulty, discrimination, thetas)
     """
-    if seed:
-        np.random.seed(seed)
+    rng = np.random.default_rng(seed)
 
     # If the input is just a vector of discriminations
     if (np.ndim(discrimination) == 1) or (discrimination.shape[0] == 1):
@@ -101,7 +105,7 @@ def create_synthetic_mirt_dichotomous(difficulty, discrimination, thetas,
     continuous_output = 1.0 / (1.0 + np.exp(-kernel_terms))
 
     # convert to binary based on probability
-    random_compare = np.random.rand(*continuous_output.shape)
+    random_compare = rng.uniform(size=continuous_output.shape)
 
     return (random_compare <= continuous_output).astype('int')
 
@@ -233,8 +237,7 @@ def create_synthetic_irt_polytomous(difficulty, discrimination, thetas,
     if n_levels == 1:
         raise AssertionError("Polytomous items must have more than 1 threshold")
 
-    if seed:
-        np.random.seed(seed)
+    rng = np.random.default_rng(seed)
 
     # Check for single input of discrimination
     if np.atleast_1d(discrimination).size == 1:
@@ -262,7 +265,7 @@ def create_synthetic_irt_polytomous(difficulty, discrimination, thetas,
 
         # Get the thresholds of the levels
         np.cumsum(level_scratch[1:, :], axis=0, out=level_scratch[1:, :])
-        level_scratch[0] = np.random.rand(thetas.size)
+        level_scratch[0] = rng.uniform(size=thetas.size)
 
         # Discritize the outputs based on the thresholds
         output[item_ndx] = np.apply_along_axis(
